==> kendo-react-scheduler-11.0.0.tgz: package/README.md <==
[![KendoReact NPM Banner](https://raw.githubusercontent.com/telerik/kendo-react/master/images/kendoreact-github-banner.png)](https://www.telerik.com/kendo-react-ui/components/free?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler&utm_content=banner)

# KendoReact Scheduler Component for React

> **Important**
>
> -   This package is а part of [KendoReact](https://www.telerik.com/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;an enterprise-grade UI library with 120+ free and premium components.
> -   It provides a premium KendoReact component. You will need to install a license key when adding the package to your project. For more information, please refer to the [KendoReact My License page](https://www.telerik.com/kendo-react-ui/components/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler).
> -   To receive a license key, you need to either [purchase a license](https://www.telerik.com/kendo-react-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) or register for a [free trial](https://www.telerik.com/try/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler). Doing so indicates that you [accept the KendoReact License Agreement](https://www.telerik.com/purchase/license-agreement/progress-kendoreact?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler).
> -   The 30-day free trial gives you access to all KendoReact components and their full functionality. Additionally, for the period of your trial, you can use our legendary technical support provided directly by the KendoReact dev team!
>
> [Start using KendoReact](https://www.telerik.com/try/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) and speed up your development process!
>
> If you're looking for free React components, check out [Get Started with KendoReact Free](https://www.telerik.com/kendo-react-ui/components/free).

The [React Scheduler](https://www.telerik.com/kendo-react-ui/scheduler), part of KendoReact, provides out-of-the-box support for timezone conversion, resources visualization, grouping, editing, and recurring events.

## React Scheduler

The KendoReact Scheduler component is built on React from the ground up by developers with 19+ years of experience in making enterprise-ready components. This results in a React scheduling component that delivers lightning fast performance and is highly customizable.

Among the many features which the KendoReact Scheduler delivers are:

-   [Multiple views](https://www.telerik.com/kendo-react-ui/components/scheduler/views/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can display the Scheduler events in any of the available Timeline, Day, Week, Month, or Agenda views.
-   [Editing](https://www.telerik.com/kendo-react-ui/components/scheduler/editing/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can create, update, and delete events displayed by the Scheduler allowing for a fast and easy rescheduling.
-   [Grouping](https://www.telerik.com/kendo-react-ui/components/scheduler/grouping/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;The Scheduler enables grouping by different resources like meeting rooms, teams, and more, which provides a nice arrangement of the events within the same group.
-   [Resources](https://www.telerik.com/kendo-react-ui/components/scheduler/resources/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;Define different custom resources such as available conference rooms or guest lists for the Scheduler to work with.
-   [Recurring events](https://www.telerik.com/kendo-react-ui/components/scheduler/recurring/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can schedule a recurring event that will occur on a specific day, for example, each Monday during the next year.
-   [Controlled and uncontrolled mode for the date selection](https://www.telerik.com/kendo-react-ui/components/scheduler/date-selection/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;This capability allows you to completely override the date selection from outside the Scheduler.
-   [Timezones](https://www.telerik.com/kendo-react-ui/components/scheduler/timezones/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can display the events in the Scheduler in different timezones when building multinational applications.
-   [Globalization](https://www.telerik.com/kendo-react-ui/components/scheduler/timezones/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;The globalization process combines the translation of component messages with adapting them to specific cultures
-   [Theme support](https://www.telerik.com/kendo-react-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;The KendoReact Scheduler, as well as all 100+ components in the KendoReact suite, are styled in three polished themes (Bootstrap, Material, and Default) and can be further customized to match your specific design guidelines.

## Support Options

For any issues you might encounter while working with the KendoReact Scheduler, use any of the available support channels:

-   Industry-leading technical support&mdash;KendoReact paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated KendoReact support system](https://www.telerik.com/account/support-center/contact-us/technical-support?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler).
-   Product forums&mdash;The [KendoReact forums](https://www.telerik.com/forums/kendo-ui-react?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) are part of the free support you can get from the community and from the KendoReact team.
-   Feedback portal&mdash;The [KendoReact feedback portal](https://feedback.telerik.com/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) is where you can request and vote for new features to be added.

## Resources

-   [Getting Started with KendoReact](https://www.telerik.com/kendo-react-ui/components/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Get Started with KendoReact Free](https://www.telerik.com/kendo-react-ui/components/free)
-   [Getting Started with the KendoReact Scheduler](https://www.telerik.com/kendo-react-ui/components/scheduler/get-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [API Reference of the KendoReact Scheduler](https://www.telerik.com/kendo-react-ui/components/scheduler/api/SchedulerProps/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [KendoReact Roadmap](https://www.telerik.com/support/whats-new/kendo-react-ui/roadmap?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Blogs](https://www.telerik.com/blogs/tag/kendoreact?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Demos, documentation, and component reference](https://www.telerik.com/kendo-react-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [KendoReact pricing and licensing](https://www.telerik.com/kendo-react-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Changelog](https://www.telerik.com/kendo-react-ui/components/changelogs/ui-for-react/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)

High-level component overview pages

-   [React Scheduler Component](https://www.telerik.com/kendo-react-ui/scheduler)

_Copyright © 2024 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved._

_Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries._

==> kendo-react-scheduler-11.1.0.tgz: package/README.md <==
[![KendoReact NPM Banner](https://raw.githubusercontent.com/telerik/kendo-react/master/images/kendoreact-github-banner.png)](https://www.telerik.com/kendo-react-ui/components/free?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler&utm_content=banner)

# KendoReact Scheduler Component for React

> **Important**
>
> -   This package is а part of [KendoReact](https://www.telerik.com/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;an enterprise-grade UI library with 120+ free and premium components.
> -   It provides a premium KendoReact component. You will need to install a license key when adding the package to your project. For more information, please refer to the [KendoReact My License page](https://www.telerik.com/kendo-react-ui/components/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler).
> -   To receive a license key, you need to either [purchase a license](https://www.telerik.com/kendo-react-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) or register for a [free trial](https://www.telerik.com/try/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler). Doing so indicates that you [accept the KendoReact License Agreement](https://www.telerik.com/purchase/license-agreement/progress-kendoreact?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler).
> -   The 30-day free trial gives you access to all KendoReact components and their full functionality. Additionally, for the period of your trial, you can use our legendary technical support provided directly by the KendoReact dev team!
>
> [Start using KendoReact](https://www.telerik.com/try/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) and speed up your development process!
>
> If you're looking for free React components, check out [Get Started with KendoReact Free](https://www.telerik.com/kendo-react-ui/components/free).

The [React Scheduler](https://www.telerik.com/kendo-react-ui/components/scheduler), part of KendoReact, provides out-of-the-box support for timezone conversion, resources visualization, grouping, editing, and recurring events.

## React Scheduler

The KendoReact Scheduler component is built on React from the ground up by developers with 19+ years of experience in making enterprise-ready components. This results in a React scheduling component that delivers lightning fast performance and is highly customizable.

Among the many features which the KendoReact Scheduler delivers are:

-   [Multiple views](https://www.telerik.com/kendo-react-ui/components/scheduler/views/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can display the Scheduler events in any of the available Timeline, Day, Week, Month, or Agenda views.
-   [Editing](https://www.telerik.com/kendo-react-ui/components/scheduler/editing/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can create, update, and delete events displayed by the Scheduler allowing for a fast and easy rescheduling.
-   [Grouping](https://www.telerik.com/kendo-react-ui/components/scheduler/grouping/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;The Scheduler enables grouping by different resources like meeting rooms, teams, and more, which provides a nice arrangement of the events within the same group.
-   [Resources](https://www.telerik.com/kendo-react-ui/components/scheduler/resources/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;Define different custom resources such as available conference rooms or guest lists for the Scheduler to work with.
-   [Recurring events](https://www.telerik.com/kendo-react-ui/components/scheduler/recurring/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can schedule a recurring event that will occur on a specific day, for example, each Monday during the next year.
-   [Controlled and uncontrolled mode for the date selection](https://www.telerik.com/kendo-react-ui/components/scheduler/date-selection/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;This capability allows you to completely override the date selection from outside the Scheduler.
-   [Timezones](https://www.telerik.com/kendo-react-ui/components/scheduler/timezones/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;You can display the events in the Scheduler in different timezones when building multinational applications.
-   [Globalization](https://www.telerik.com/kendo-react-ui/components/scheduler/timezones/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;The globalization process combines the translation of component messages with adapting them to specific cultures
-   [Theme support](https://www.telerik.com/kendo-react-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)&mdash;The KendoReact Scheduler, as well as all 100+ components in the KendoReact suite, are styled in three polished themes (Bootstrap, Material, and Default) and can be further customized to match your specific design guidelines.

## Support Options

For any issues you might encounter while working with the KendoReact Scheduler, use any of the available support channels:

-   Industry-leading technical support&mdash;KendoReact paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated KendoReact support system](https://www.telerik.com/account/support-center/contact-us/technical-support?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler).
-   Product forums&mdash;The [KendoReact forums](https://www.telerik.com/forums/kendo-ui-react?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) are part of the free support you can get from the community and from the KendoReact team.
-   Feedback portal&mdash;The [KendoReact feedback portal](https://feedback.telerik.com/kendo-react-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler) is where you can request and vote for new features to be added.

## Resources

-   [Getting Started with KendoReact](https://www.telerik.com/kendo-react-ui/components/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Get Started with KendoReact Free](https://www.telerik.com/kendo-react-ui/components/free)
-   [Getting Started with the KendoReact Scheduler](https://www.telerik.com/kendo-react-ui/components/scheduler/get-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [API Reference of the KendoReact Scheduler](https://www.telerik.com/kendo-react-ui/components/scheduler/api/SchedulerProps/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [KendoReact Roadmap](https://www.telerik.com/support/whats-new/kendo-react-ui/roadmap?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Blogs](https://www.telerik.com/blogs/tag/kendoreact?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Demos, documentation, and component reference](https://www.telerik.com/kendo-react-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [KendoReact pricing and licensing](https://www.telerik.com/kendo-react-ui/pricing?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)
-   [Changelog](https://www.telerik.com/kendo-react-ui/components/changelogs/ui-for-react/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-react-trial-npm-scheduler)

High-level component overview pages

-   [React Scheduler Component](https://www.telerik.com/kendo-react-ui/scheduler)

_Copyright © 2024 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved._

_Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries._
